'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var got = require('got');
var logger = require('@dnpr/logger');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var got__default = /*#__PURE__*/_interopDefaultLegacy(got);

const log = new logger.Logger("notionapi-agent");

const Default = {
  server: "https://www.notion.so",
  userAgent: "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.130 Safari/537.36"
};

class APIError extends Error {
  name = "APIError";
  constructor(error) {
    super();
    Object.setPrototypeOf(this, APIError.prototype);
    this.message = `Server says "${error.name}: ${error.message}`;
    if (error.status) {
      this.message += ` Status: ${error.status}`;
    }
    this.message += '"';
  }
}

function createAPI(url, token) {
  log.debug(`agent.ts: Create API function with URL "${url}"`);
  return async function(req) {
    log.debug(`agent.ts: Call API "${url}".`);
    let data;
    try {
      const _data = await got__default["default"].post(url, {
        headers: {
          "accept": "*/*",
          "accept-language": "en-US,en;q=0.9",
          "cookie": `token_v2=${token};`,
          "origin": Default.server,
          "referer": Default.server,
          "user-agent": Default.userAgent
        },
        json: req
      }).json();
      data = _data;
    } catch (error) {
      const errorInfo = JSON.parse(error.response.body);
      if (errorInfo.hasOwnProperty("errorId")) {
        throw new APIError(errorInfo);
      }
    }
    console.log(data);
    return data;
  };
}
function createAgent(opts = {}) {
  const token = opts.token ? opts.token : "";
  const server = opts.server ? opts.server : Default.server;
  if (opts.debug) {
    log.setLogLevel("debug");
  }
  log.debug(`agent.ts: Create API agent with server "${server}" and token "${token.substr(0, 9)}..."`);
  const getActivityLog = createAPI(
    `${server}/api/v3/getActivityLog`,
    token
  );
  const getAssetsJson = createAPI(
    `${server}/api/v3/getAssetsJson`,
    token
  );
  const getRecordValues = createAPI(
    `${server}/api/v3/getRecordValues`,
    token
  );
  const getSnapshotsList = createAPI(
    `${server}/api/v3/getSnapshotsList`,
    token
  );
  const getUserSharedPages = createAPI(
    `${server}/api/v3/getUserSharedPages`,
    token
  );
  const loadPageChunk = createAPI(
    `${server}/api/v3/loadPageChunk`,
    token
  );
  const loadUserContent = createAPI(
    `${server}/api/v3/loadUserContent`,
    token
  );
  const queryCollection = createAPI(
    `${server}/api/v3/queryCollection`,
    token
  );
  const submitTransaction = createAPI(
    `${server}/api/v3/submitTransaction`,
    token
  );
  return {
    getActivityLog,
    getAssetsJson,
    getRecordValues,
    getSnapshotsList,
    getUserSharedPages,
    loadPageChunk,
    loadUserContent,
    queryCollection,
    submitTransaction
  };
}

exports.createAgent = createAgent;
//# sourceMappingURL=index.js.map
